@@ -1,18 +1,8 @@
 /*
-  This file is part of CDO. CDO is a collection of Operators to
-  manipulate and analyse Climate model Data.
+  This file is part of CDO. CDO is a collection of Operators to manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2021 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
-  See COPYING file for copying and redistribution conditions.
+  Author: Uwe Schulzweida
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; version 2 of the License.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
 */
 
 /*
@@ -484,9 +474,7 @@ gen_mapdata(int gridID1, int gridID2)
   StatInfo statInfo;
 
 #ifdef _OPENMP
-#pragma omp parallel for default(none) schedule(dynamic)                                                                          \
-    shared(Options::cdoVerbose, gridsize2, gps, statInfo, mapdata, xvals1, yvals1, xvals2, yvals2, grid2_is_reg2d, ndist_max, nv, \
-           nlon2, xbounds2d, ybounds2d, xbounds, ybounds, adds_2D, dist_2D, vmask)
+#pragma omp parallel for default(shared) schedule(dynamic)
 #endif
   for (size_t i = 0; i < gridsize2; ++i)
     {
@@ -570,11 +558,11 @@ remap_field(const Varray2D<size_t> &mapdata, const Field &field1, Field &field2,
   std::vector<Field> fields(Threading::ompNumThreads);
 
   auto gridsize2 = gridInqSize(field2.grid);
-  auto start = Options::cdoVerbose ? cdo_get_wtime() : 0.0;
+  const auto start = Options::cdoVerbose ? cdo_get_wtime() : 0.0;
 
   size_t nmiss2 = 0;
 #ifdef _OPENMP
-#pragma omp parallel for default(none) schedule(static) reduction(+ : nmiss2) shared(operfunc, gridsize2, mapdata, fields, field1, field2)
+#pragma omp parallel for default(shared) schedule(static) reduction(+ : nmiss2)
 #endif
   for (size_t i = 0; i < gridsize2; ++i)
     {
