@@ -1,21 +1,11 @@
 /*
-  This file is part of CDO. CDO is a collection of Operators to
-  manipulate and analyse Climate model Data.
+  This file is part of CDO. CDO is a collection of Operators to manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2020 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
-  See COPYING file for copying and redistribution conditions.
+  Author: Uwe Schulzweida
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; version 2 of the License.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
 */
 
-#include <algorithm> // sort
+#include <algorithm>  // sort
 
 #include <cdi.h>
 
@@ -56,7 +46,7 @@ free_cellindex(CellIndex *cellindex)
 static CellIndex *
 read_cellindex(const std::string &filename)
 {
-  const auto streamID = streamOpenReadLocked(filename.c_str());
+  const auto streamID = stream_open_read_locked(filename.c_str());
   const auto vlistID = streamInqVlist(streamID);
   const auto ngrids = vlistNgrids(vlistID);
   int gridID = -1;
@@ -66,7 +56,7 @@ read_cellindex(const std::string &filename)
       if (gridInqType(gridID) == GRID_UNSTRUCTURED && gridInqNvertex(gridID) == 3) break;
     }
 
-  if (gridID == -1) cdoAbort("No ICON grid found in %s!", filename);
+  if (gridID == -1) cdo_abort("No ICON grid found in %s!", filename);
 
   // int nid = CDI_UNDEFID;
   int pid = CDI_UNDEFID;
@@ -97,9 +87,9 @@ read_cellindex(const std::string &filename)
       */
     }
 
-  // if (nid == CDI_UNDEFID) cdoAbort("neighbor_cell_index not found in %s!", filename);
-  // if (pid == CDI_UNDEFID) cdoAbort("parent_cell_index not found in %s!", filename);
-  // if (cid == CDI_UNDEFID) cdoAbort("child_cell_index not found in %s!", filename);
+  // if (nid == CDI_UNDEFID) cdo_abort("neighbor_cell_index not found in %s!", filename);
+  // if (pid == CDI_UNDEFID) cdo_abort("parent_cell_index not found in %s!", filename);
+  // if (cid == CDI_UNDEFID) cdo_abort("child_cell_index not found in %s!", filename);
 
   const long ncells = gridInqSize(gridID);
 
@@ -124,9 +114,9 @@ read_cellindex(const std::string &filename)
       if (varID == pid /* || varID == nid || varID == cid */)
         {
           streamReadRecord(streamID, data.data(), &nmiss);
-          if (varID == pid)
+          // if (varID == pid)
             {
-              if (Options::cdoVerbose) cdoPrint("Read parent_cell_index");
+              if (Options::cdoVerbose) cdo_print("Read parent_cell_index");
               copy_data_to_index(ncells, data, cellindex->parent);
             }
           // else if ( varID == nid ) copy_data_to_index(ncells, data, cellindex->neighbor+levelID*ncells);
@@ -146,7 +136,7 @@ read_cellindex(const std::string &filename)
 static int
 read_grid(const char *filename)
 {
-  const auto streamID = streamOpenReadLocked(filename);
+  const auto streamID = stream_open_read_locked(filename);
   const auto vlistID = streamInqVlist(streamID);
   const auto ngrids = vlistNgrids(vlistID);
   int gridID = -1;
@@ -156,7 +146,7 @@ read_grid(const char *filename)
       if (gridInqType(gridID) == GRID_UNSTRUCTURED && gridInqNvertex(gridID) == 3) break;
     }
 
-  if (gridID == -1) cdoAbort("No ICON grid found in %s!", filename);
+  if (gridID == -1) cdo_abort("No ICON grid found in %s!", filename);
 
   const auto gridID2 = gridDuplicate(gridID);
 
@@ -219,7 +209,7 @@ cmpsinfo(const SortInfo &a, const SortInfo &b)
 static void
 compute_child_from_parent(CellIndex *cellindex1, CellIndex *cellindex2)
 {
-  if (Options::cdoVerbose) cdoPrint("%s", __func__);
+  if (Options::cdoVerbose) cdo_print("%s", __func__);
 
   const auto ncells1 = cellindex1->ncells;
   long *parent1 = cellindex1->parent;
@@ -229,7 +219,7 @@ compute_child_from_parent(CellIndex *cellindex1, CellIndex *cellindex2)
   for (long i = 1; i < ncells1; ++i)
     if (parent1[i] < parent1[i - 1])
       {
-        if (Options::cdoVerbose) cdoPrint("Sort parent index of %s!", cellindex1->filename);
+        if (Options::cdoVerbose) cdo_print("Sort parent index of %s!", cellindex1->filename);
         std::vector<SortInfo> sinfo(ncells1);
         for (long j = 0; j < ncells1; ++j)
           {
@@ -276,7 +266,7 @@ read_coordinates(const char *filename, long n, double *lon, double *lat, int nv,
       if (gridInqType(gridID) == GRID_UNSTRUCTURED && (long) gridInqSize(gridID) == n && gridInqNvertex(gridID) == 3) break;
     }
 
-  if (gridID == -1) cdoAbort("No ICON grid with %ld cells found in %s!", n, filename);
+  if (gridID == -1) cdo_abort("No ICON grid with %ld cells found in %s!", n, filename);
 
   gridInqXvals(gridID, lon);
   gridInqYvals(gridID, lat);
@@ -297,21 +287,21 @@ read_coordinates(const char *filename, long n, double *lon, double *lat, int nv,
   streamClose(streamID);
 }
 
-constexpr int MAX_SEARCH = 128; // the triangles are distorted!
+constexpr int MAX_SEARCH = 128;  // the triangles are distorted!
 
 static void
 compute_child_from_bounds(CellIndex *cellindex2, long ncells2, double *grid_center_lon2, double *grid_center_lat2,
                           double *grid_corner_lon2, double *grid_corner_lat2, long ncells1, const Varray<double> &grid_center_lon1,
                           const Varray<double> &grid_center_lat1)
 {
-  if (Options::cdoVerbose) cdoPrint("%s", __func__);
+  if (Options::cdoVerbose) cdo_print("%s", __func__);
 
   bool xIsCyclic = false;
   size_t dims[2];
   dims[0] = ncells1;
   dims[1] = 0;
   GridPointSearch gps;
-  gridPointSearchCreate(gps, xIsCyclic, dims, ncells1, grid_center_lon1, grid_center_lat1);
+  grid_point_search_create(gps, xIsCyclic, dims, ncells1, grid_center_lon1, grid_center_lat1);
   knnWeightsType knnWeights(MAX_SEARCH);
   size_t *nbr_addr = &knnWeights.m_addr[0];
 
@@ -333,7 +323,8 @@ compute_child_from_bounds(CellIndex *cellindex2, long ncells2, double *grid_cent
       const auto coordinate_to_ignore = find_coordinate_to_ignore(cell_corners_xyz);
 
       bool invert_result = false;
-      const auto cval = (coordinate_to_ignore == 1) ? cell_corners_xyz[0].X : ((coordinate_to_ignore == 2) ? cell_corners_xyz[0].Y : cell_corners_xyz[0].Z);
+      const auto cval = (coordinate_to_ignore == 1) ? cell_corners_xyz[0].X
+                                                    : ((coordinate_to_ignore == 2) ? cell_corners_xyz[0].Y : cell_corners_xyz[0].Z);
       if (cval < 0.0) invert_result = true;
 
       set_cell_corners_plane_projection(coordinate_to_ignore, ncorner, cell_corners_xyz, cell_corners_plane_projection);
@@ -344,7 +335,7 @@ compute_child_from_bounds(CellIndex *cellindex2, long ncells2, double *grid_cent
       if (invert_result) is_clockwise = !is_clockwise;
       if (is_clockwise) continue;
 
-      gridSearchPoint(gps, grid_center_lon2[cell_no2], grid_center_lat2[cell_no2], knnWeights);
+      grid_search_point(gps, grid_center_lon2[cell_no2], grid_center_lat2[cell_no2], knnWeights);
       int k = 0;
 
       double center_coordinates[3];
@@ -369,7 +360,7 @@ compute_child_from_bounds(CellIndex *cellindex2, long ncells2, double *grid_cent
               // RAD2DEG*grid_center_lat1[cell_no1], winding_number);
               if (winding_number != 0)
                 {
-                  if (k >= MAX_CHILDS) cdoAbort("Internal problem, limit of MAX_CHILDS reached (limit=9).");
+                  if (k >= MAX_CHILDS) cdo_abort("Internal problem, limit of MAX_CHILDS reached (limit=9).");
                   child2[cell_no2 * MAX_CHILDS + k++] = (long) cell_no1;
                 }
             }
@@ -377,13 +368,13 @@ compute_child_from_bounds(CellIndex *cellindex2, long ncells2, double *grid_cent
       // printf("%d k = %d\n", cell_no2, k);
     }
 
-  gridPointSearchDelete(gps);
+  grid_point_search_delete(gps);
 }
 
 static void
 compute_child_from_coordinates(CellIndex *cellindex1, CellIndex *cellindex2)
 {
-  if (Options::cdoVerbose) cdoPrint("%s", __func__);
+  if (Options::cdoVerbose) cdo_print("%s", __func__);
 
   const auto ncells1 = cellindex1->ncells;
   const auto ncells2 = cellindex2->ncells;
@@ -415,7 +406,7 @@ compute_child(CellIndex *cellindex1, CellIndex *cellindex2)
   else
     {
       compute_child_from_coordinates(cellindex1, cellindex2);
-      // cdoAbort("Missing parent index of %s!", cellindex1->filename);
+      // cdo_abort("Missing parent index of %s!", cellindex1->filename);
     }
 }
 
@@ -424,7 +415,7 @@ compute_sum(long i, long &n, double &sum, double &sumq, long kci, CellIndex **ce
 {
   // printf("compute: i, kci %d %d\n", i, kci);
   const auto ncells2 = cellindex[kci]->ncells;
-  if (i < 0 || i > ncells2) cdoAbort("Child grid cell index %ld out of bounds %ld!", i, ncells2);
+  if (i < 0 || i > ncells2) cdo_abort("Child grid cell index %ld out of bounds %ld!", i, ncells2);
 
   for (int k = 0; k < MAX_CHILDS; ++k)
     {
@@ -451,7 +442,7 @@ samplegrid(double missval, long nci, CellIndex **cellindex, const Varray<double>
   long nx = 0;
   double x = 0;
 #ifdef _OPENMP
-//#pragma omp parallel for default(none) shared(missval, ncells2, kci, cellindex, array1, array2, array3)
+//#pragma omp parallel for default(shared)
 #endif
   for (long i = 0; i < ncells2; ++i)
     {
@@ -461,7 +452,7 @@ samplegrid(double missval, long nci, CellIndex **cellindex, const Varray<double>
       array2[i] = n ? sum / n : missval;  // mean
       double var1 = (n * n > n) ? (sumq * n - sum * sum) / (n * n - n) : missval;
       if (var1 < 0 && var1 > -1.e-5) var1 = 0;
-      array3[i] = varToStd(var1, missval);  // std1
+      array3[i] = var_to_std(var1, missval);  // std1
       if (lstat && n)
         {
           nx++;
@@ -471,40 +462,40 @@ samplegrid(double missval, long nci, CellIndex **cellindex, const Varray<double>
   if (Options::cdoVerbose && lstat)
     {
       lstat = false;
-      cdoPrint("Mean number of childs %g", nx ? x / nx : 0);
+      cdo_print("Mean number of childs %g", nx ? x / nx : 0);
     }
 }
 
 void *
 Samplegridicon(void *process)
 {
-  cdoInitialize(process);
+  cdo_initialize(process);
 
-  cdoOperatorAdd("samplegridicon", 0, 0, "sample grids");
+  cdo_operator_add("samplegridicon", 0, 0, "sample grids");
 
-  const auto nsamplegrids = operatorArgc();
-  if (nsamplegrids < 2) cdoAbort("Parameter missing!");
+  const auto nsamplegrids = cdo_operator_argc();
+  if (nsamplegrids < 2) cdo_abort("Parameter missing!");
 
   std::vector<CellIndex *> cellindex(nsamplegrids);
 
   for (int i = 0; i < nsamplegrids; ++i)
     {
-      cellindex[i] = read_cellindex(cdoOperatorArgv(i));
-      cellindex[i]->filename = cdoOperatorArgv(i).c_str();
-      if (Options::cdoVerbose) cdoPrint("Found %ld grid cells in %s", cellindex[i]->ncells, cellindex[i]->filename);
+      cellindex[i] = read_cellindex(cdo_operator_argv(i));
+      cellindex[i]->filename = cdo_operator_argv(i).c_str();
+      if (Options::cdoVerbose) cdo_print("Found %ld grid cells in %s", cellindex[i]->ncells, cellindex[i]->filename);
     }
 
   for (int i = 0; i < nsamplegrids - 1; ++i) compute_child(cellindex[i], cellindex[i + 1]);
 
-  const auto gridID2 = read_grid(cdoOperatorArgv(nsamplegrids - 1).c_str());
+  const auto gridID2 = read_grid(cdo_operator_argv(nsamplegrids - 1).c_str());
 
-  const auto streamID1 = cdoOpenRead(0);
-  const auto vlistID1 = cdoStreamInqVlist(streamID1);
+  const auto streamID1 = cdo_open_read(0);
+  const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
 
   long gridsize = vlistGridsizeMax(vlistID1);
-  if (Options::cdoVerbose) cdoPrint("Source gridsize = %zu", gridsize);
+  if (Options::cdoVerbose) cdo_print("Source gridsize = %zu", gridsize);
   if (gridsize != cellindex[0]->ncells)
-    cdoAbort("Gridsize (%ld) of input stream and first grid (%ld) differ!", gridsize, cellindex[0]->ncells);
+    cdo_abort("Gridsize (%ld) of input stream and first grid (%ld) differ!", gridsize, cellindex[0]->ncells);
   if (vlistNumber(vlistID1) != CDI_REAL) gridsize *= 2;
   Varray<double> array1(gridsize);
 
@@ -523,67 +514,67 @@ Samplegridicon(void *process)
       const auto gridID = vlistGrid(vlistID1, index);
       const auto gridtype = gridInqType(gridID);
       if (!(gridtype == GRID_UNSTRUCTURED && gridInqNvertex(gridID) == 3))
-        cdoAbort("Unsupported gridtype: %s with %d corners", gridNamePtr(gridtype), gridInqNvertex(gridID));
+        cdo_abort("Unsupported gridtype: %s with %d corners", gridNamePtr(gridtype), gridInqNvertex(gridID));
 
       vlistChangeGridIndex(vlistID2, index, gridID2);
       vlistChangeGridIndex(vlistID3, index, gridID2);
     }
 
-  const auto streamID2 = cdoOpenWrite(1);
-  cdoDefVlist(streamID2, vlistID2);
+  const auto streamID2 = cdo_open_write(1);
+  cdo_def_vlist(streamID2, vlistID2);
 
-  const auto streamID3 = cdoOpenWrite(2);
-  cdoDefVlist(streamID3, vlistID3);
+  const auto streamID3 = cdo_open_write(2);
+  cdo_def_vlist(streamID3, vlistID3);
 
   auto gridsize2 = gridInqSize(gridID2);
-  if (Options::cdoVerbose) cdoPrint("Target gridsize = %ld", gridsize2);
+  if (Options::cdoVerbose) cdo_print("Target gridsize = %ld", gridsize2);
   if (vlistNumber(vlistID2) != CDI_REAL) gridsize2 *= 2;
   Varray<double> array2(gridsize2), array3(gridsize2);
 
   int tsID = 0;
   while (true)
     {
-      const auto nrecs = cdoStreamInqTimestep(streamID1, tsID);
+      const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
       if (nrecs == 0) break;
 
-      taxisCopyTimestep(taxisID2, taxisID1);
-      taxisCopyTimestep(taxisID3, taxisID1);
-      cdoDefTimestep(streamID2, tsID);
-      cdoDefTimestep(streamID3, tsID);
+      cdo_taxis_copy_timestep(taxisID2, taxisID1);
+      cdo_taxis_copy_timestep(taxisID3, taxisID1);
+      cdo_def_timestep(streamID2, tsID);
+      cdo_def_timestep(streamID3, tsID);
 
       for (int recID = 0; recID < nrecs; recID++)
         {
           int varID, levelID;
-          cdoInqRecord(streamID1, &varID, &levelID);
+          cdo_inq_record(streamID1, &varID, &levelID);
           size_t nmiss;
-          cdoReadRecord(streamID1, array1.data(), &nmiss);
+          cdo_read_record(streamID1, array1.data(), &nmiss);
 
           const auto missval = vlistInqVarMissval(vlistID1, varID);
 
           samplegrid(missval, nsamplegrids, &cellindex[0], array1, array2, array3);
 
-          nmiss = varrayNumMV(gridsize2, array2, missval);
-          cdoDefRecord(streamID2, varID, levelID);
-          cdoWriteRecord(streamID2, array2.data(), nmiss);
+          nmiss = varray_num_mv(gridsize2, array2, missval);
+          cdo_def_record(streamID2, varID, levelID);
+          cdo_write_record(streamID2, array2.data(), nmiss);
 
-          nmiss = varrayNumMV(gridsize2, array3, missval);
-          cdoDefRecord(streamID3, varID, levelID);
-          cdoWriteRecord(streamID3, array3.data(), nmiss);
+          nmiss = varray_num_mv(gridsize2, array3, missval);
+          cdo_def_record(streamID3, varID, levelID);
+          cdo_write_record(streamID3, array3.data(), nmiss);
         }
 
       tsID++;
     }
 
-  cdoStreamClose(streamID3);
-  cdoStreamClose(streamID2);
-  cdoStreamClose(streamID1);
+  cdo_stream_close(streamID3);
+  cdo_stream_close(streamID2);
+  cdo_stream_close(streamID1);
 
   vlistDestroy(vlistID2);
   gridDestroy(gridID2);
 
   for (int i = 0; i < nsamplegrids; ++i) free_cellindex(cellindex[i]);
 
-  cdoFinish();
+  cdo_finish();
 
   return nullptr;
 }
