@@ -1,25 +1,9 @@
-/*
-  This file is part of CDO. CDO is a collection of Operators to
-  manipulate and analyse Climate model Data.
-
-  Copyright (C) 2003-2021 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
-  See COPYING file for copying and redistribution conditions.
-
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; version 2 of the License.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-*/
-
 #include <algorithm>
 
 #include "cdi.h"
 
 #include "cimdOmp.h"
+
 #define streamDefRecord cdo_def_record
 #define streamWriteRecord cdo_write_record
 
@@ -960,7 +944,7 @@ MakeGeopotHeight(double *geop, double *gt, double *gq, double *ph, int nhor, int
   const double vtmp = (C_RV / PlanetRD) - 1.0;
   const double zrg = 1.0 / PlanetGrav;
 
-  if (gq) /* Humidity is present */
+  if (gq) // Humidity is present
     {
       for (int j = nlev; j > 1; j--)
         {
@@ -2647,17 +2631,14 @@ after_EchamDependencies(struct Variable *vars, int ncodes, int type, int source)
   CheckDependencies(vars, 0);
 }
 
-void after_legini_full(long ntr, long nlat, double *restrict poli, double *restrict pold, double *restrict pdev,
-                       double *restrict pol2, double *restrict pol3, double *restrict coslat);
-void after_legini(long ntr, long nlat, double *restrict poli, double *restrict pold, double *restrict coslat);
 
 void
 after_legini_setup(AfterControl &globs, struct Variable *vars)
 {
-  long ntr = globs.Truncation;
-  long nlat = globs.Latitudes;
-  long dimsp = (ntr + 1) * (ntr + 2);
-  long pdim = dimsp / 2 * nlat;
+  const long ntr = globs.Truncation;
+  const long nlat = globs.Latitudes;
+  const long dimsp = (ntr + 1) * (ntr + 2);
+  const long pdim = (dimsp / 2) * nlat;
 
   globs.poli = (double *) Malloc(pdim * sizeof(double));
 
@@ -2693,14 +2674,7 @@ after_legini_setup(AfterControl &globs, struct Variable *vars)
       return;
     }
 
-  int flag = 1;
-  // if ( globs.poli && globs.pold && globs.pdev == nullptr && globs.pol2 ==
-  // nullptr && globs.pol3 == nullptr ) flag = 0;
-
-  if (flag)
-    after_legini_full(ntr, nlat, globs.poli, globs.pold, globs.pdev, globs.pol2, globs.pol3, globs.coslat);
-  else
-    after_legini(ntr, nlat, globs.poli, globs.pold, globs.coslat);
+  after_legini_full(ntr, nlat, globs.poli, globs.pold, globs.pdev, globs.pol2, globs.pol3, globs.coslat);
 
   for (long jgl = 0; jgl < nlat; ++jgl) globs.rcoslat[jgl] = 1.0 / globs.coslat[jgl];
 
